#[derive(FromRequest)]Expand description
Implements a FromRequest for a struct that holds cookie types
Note: only allows structs with either a single unnamed field or multiple unnamed fields
#[derive(FromRequest)]Implements a FromRequest for a struct that holds cookie types
Note: only allows structs with either a single unnamed field or multiple unnamed fields